@@ -20,6 +20,9 @@
 #' @export ecd.mpnum
 #' @export ecd.ifelse
 #' @export ecd.sapply
+#' @export ecd.mcsapply
+#'
+#' @importFrom parallel mclapply
 #'
 ### <======================================================================>
 "ecd.mpnum" <- function(object, x)
@@ -39,3 +42,9 @@
     ecd.mpnum(object, rs)
 }
 ### <---------------------------------------------------------------------->
+#' @rdname ecd.mpnum
+"ecd.mcsapply" <- function(object, x, FUN, ...) {
+    rs <- simplify2array(parallel::mclapply(x, FUN, ...))
+    ecd.mpnum(object, rs)
+}
+### <---------------------------------------------------------------------->
